@@ -17,7 +17,7 @@ plot_stimuli <- function(object, rev_color = FALSE, alpha = .55) {
   cuts = (-5:6 - .5) * max(abs(pd$s_label$x)) * 2 / 10
   cats <- as.numeric(cut(pd$s_label$x, breaks = cuts))
 
-  p <- ggplot2::ggplot(pd$s_draws, ggplot2::aes(.data$value, fill = .data$name, color = .data$name)) + ggplot2::geom_density(alpha = alpha) +
+  p <- ggplot2::ggplot(pd$s_draws, ggplot2::aes(.data$value, fill = .data$name, color = .data$name)) + ggplot2::geom_density(alpha = alpha, trim = TRUE, outline.type = "full") +
     ggplot2::geom_text(data = pd$s_label, ggplot2::aes(x = .data$x, y = 0, label = .data$name), hjust = 0, nudge_x = -.007,
               nudge_y = .025 * max(pd$s_label$mode_y), check_overlap = TRUE, angle = 90, color = "black") +
     ggplot2::labs(x = "Ideological scale", y = "Posterior density") +
